"""sagellm-compression: Model Compression & Acceleration Module for sageLLM."""

from __future__ import annotations

__version__ = "0.3.0.4"

# Public API will be defined here after Task3.1-3.5 implementation
# Expected exports:
# - QuantizationConfig
# - SparsityConfig
# - SpeculativeDecoder
# - KernelFusion

__all__ = [
    "__version__",
]
